=======================
PyAMS thesaurus package
=======================

.. contents::


What is PyAMS?
==============

PyAMS (Pyramid Application Management Suite) is a small suite of packages written for applications
and content management with the Pyramid framework.

**PyAMS** is actually mainly used to manage web sites through content management applications (CMS,
see PyAMS_content package), but many features are generic and can be used inside any kind of web
application.

All PyAMS documentation is available on `ReadTheDocs <https://pyams.readthedocs.io>`_; source code
is available on `Gitlab <https://gitlab.com/pyams>`_ and pushed to `Github
<https://github.com/py-ams>`_. Doctests are available in the *doctests* source folder.


What is PyAMS thesaurus?
========================

PyAMS_thesaurus is an extension package for PyAMS which can be used to manage thesaurus. A
thesaurus is a hierarchical structure of terms, which can also handle synonyms and horizontal
associations between terms. Thesaurus can be used to classify documents, and to search contents
based on those terms associations.

Thesaurus terms can be entered manually, but also loaded from external sources like XML files
using SKOS/RDF namespace.
